/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef elgyh
#define elgyh

#include <QIcon>
#include <QSvgRenderer>
#include <QString>
#include <con.h>

class elgy: public QObject
<%
	Q_OBJECT
	public:
		elgy(QObject *felvnl);
		~elgy();
		elgy(QObject *felvnl, QString bprl, QString sima);

		QString kidlgz;
		QString eler;
		QString irnyjl;
		QSvgRenderer *adelk;

		QSvgRenderer* prmz();

		const QIcon kitzjl();
%>;

#endif

